@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_contents.py 4631 2006-06-22 19:05:20Z goodger $
+# $Id: test_contents.py 5889 2009-04-01 20:00:21Z gbrandl $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -155,7 +155,7 @@ totest['contents'] = [
         <literal_block xml:space="preserve">
             .. contents::
                :depth: two
-""" % DocutilsTestSupport.exception_data('int("two")')[1][0]],
+""" % DocutilsTestSupport.exception_data(int, "two")[1][0]],
 ["""\
 .. contents::
    :width: 2
