@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_images.py 7062 2011-06-30 22:14:29Z milde $
+# $Id: test_images.py 8024 2017-02-06 00:41:48Z goodger $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -85,6 +85,8 @@ totest['images'] = [
                :width: 200
                :scale: 50
 """],
+# If there are multiple lines in the link block, they are stripped of
+# leading and trailing whitespace and joined together:
 ["""\
 .. image:: a/very/long/path/to/
    picture.png
@@ -96,6 +98,34 @@ totest['images'] = [
 <document source="test data">
     <image height="100" scale="50" uri="a/very/long/path/to/picture.png" width="200">
 """],
+# The following two misspellings were detected in Docutils <= 0.8
+# (the option block was started by any line starting with a colon
+# which led to problems with named roles in other directives):
+["""\
+.. image:: picture.png
+   :scale 50
+""",
+"""\
+<document source="test data">
+    <image uri="picture.png:scale50">
+"""],
+["""\
+.. image:: picture.png
+   :: 50
+""",
+"""\
+<document source="test data">
+    <image uri="picture.png::50">
+"""],
+# a missing leading colon went undetected also in Docutils <= 0.8:
+["""\
+.. image:: picture.png
+   scale: 50
+""",
+"""\
+<document source="test data">
+    <image uri="picture.pngscale:50">
+"""],
 ["""\
 .. image:: picture.png
    :width: 200px
@@ -133,6 +163,22 @@ totest['images'] = [
                :height: 40%
 """],
 ["""\
+.. image:: picture.png
+   :width: 20mc
+""",
+"""\
+<document source="test data">
+    <system_message level="3" line="1" source="test data" type="ERROR">
+        <paragraph>
+            Error in "image" directive:
+            invalid option value: (option: "width"; value: \'20mc\')
+            not a positive measure of one of the following units:
+            "em" "ex" "px" "in" "cm" "mm" "pt" "pc" "%".
+        <literal_block xml:space="preserve">
+            .. image:: picture.png
+               :width: 20mc
+"""],
+["""\
 .. image:: picture.png
    :height: 100
    :width: 200
@@ -175,6 +221,7 @@ totest['images'] = [
 """ % DocutilsTestSupport.exception_data(int, None)[1][0]],
 ["""\
 .. image:: picture.png
+   :height: 100
    :scale 50
 """,
 """\
@@ -185,31 +232,10 @@ totest['images'] = [
             invalid option block.
         <literal_block xml:space="preserve">
             .. image:: picture.png
+               :height: 100
                :scale 50
 """],
 ["""\
-.. image:: picture.png
-   scale: 50
-""",
-"""\
-<document source="test data">
-    <image uri="picture.pngscale:50">
-"""],
-["""\
-.. image:: picture.png
-   :: 50
-""",
-"""\
-<document source="test data">
-    <system_message level="3" line="1" source="test data" type="ERROR">
-        <paragraph>
-            Error in "image" directive:
-            invalid option block.
-        <literal_block xml:space="preserve">
-            .. image:: picture.png
-               :: 50
-"""],
-["""\
 .. image:: picture.png
    :sale: 50
 """,
@@ -251,7 +277,7 @@ totest['images'] = [
         <literal_block xml:space="preserve">
             .. image:: picture.png
                :scale: fifty
-""" % DocutilsTestSupport.exception_data(int, "fifty")[1][0]],
+""" % DocutilsTestSupport.exception_data(int, u"fifty")[1][0]],
 ["""\
 .. image:: picture.png
    :scale: 50
@@ -406,6 +432,16 @@ u"""\
         <image uri="test.png">
     <target ids="uppercase" names="uppercase" refuri="http://docutils.sourceforge.net/">
 """],
+[r"""
+.. image:: path\ with\ spaces/name\ with\ spaces.png
+   :target: path\ with\ spaces/
+            target\ with\ spaces\ across\ lines.html
+""",
+"""\
+<document source="test data">
+    <reference refuri="path with spaces/target with spaces across lines.html">
+        <image uri="path with spaces/name with spaces.png">
+"""],
 ]
 
 
