@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# $Id: test_inline_markup.py 7942 2016-05-25 12:48:25Z milde $
+# $Id: test_inline_markup.py 8038 2017-02-16 18:03:28Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -981,6 +981,21 @@ long/path /and  /whitespace>`__
         <reference name="embedded URI with whitespace" refuri="http://example.com/long/path/and/whitespace">
             embedded URI with whitespace
 """],
+[r"""
+`embedded URI with escaped whitespace <http://example.com/a\
+long/path\ and/some\ escaped\ whitespace>`__
+
+`<omitted\ reference\ text\ with\ escaped\ whitespace>`__
+""",
+"""\
+<document source="test data">
+    <paragraph>
+        <reference name="embedded URI with escaped whitespace" refuri="http://example.com/a long/path and/some escaped whitespace">
+            embedded URI with escaped whitespace
+    <paragraph>
+        <reference name="omitted reference text with escaped whitespace" refuri="omitted reference text with escaped whitespace">
+            omitted reference text with escaped whitespace
+"""],
 ["""\
 `embedded email address <jdoe@example.com>`__
 
@@ -1140,6 +1155,15 @@ long  phrase_>`__
         <reference name="embedded alias with whitespace" refname="alias long phrase">
             embedded alias with whitespace
 """],
+["""\
+`<embedded alias with whitespace_>`__
+""",
+"""\
+<document source="test data">
+    <paragraph>
+        <reference name="embedded alias with whitespace" refname="embedded alias with whitespace">
+            embedded alias with whitespace
+"""],
 [r"""
 `no embedded alias (whitespace inside bracket) < alias_ >`__
 
@@ -1629,7 +1653,7 @@ lines.
 """],
 [u"""\
 text-*separated*\u2010*by*\u2011*various*\u2012*dashes*\u2013*and*\u2014*hyphens*.
-\u00bf*punctuation*? \u00a1*examples*!\u00a0*\u00a0no-break-space\u00a0*.
+\u00bf*punctuation*? \u00a1*examples*!\u00a0*no-break-space*\u00a0.
 """,
 u"""\
 <document source="test data">
@@ -1661,8 +1685,8 @@ u"""\
             examples
         !\xa0
         <emphasis>
-            \u00a0no-break-space\u00a0
-        .
+            no-break-space
+        \u00a0.
 """],
 # Whitespace characters:
 #  \u180e*MONGOLIAN VOWEL SEPARATOR*\u180e,   fails in Python 2.4
@@ -1767,6 +1791,110 @@ u"""\
         <emphasis>
             LINE SEPARATOR
 """],
+[u"""\
+inline markup separated by non-ASCII whitespace
+\xa0**NO-BREAK SPACE**\xa0, \xa0``NO-BREAK SPACE``\xa0, \xa0`NO-BREAK SPACE`\xa0,
+\u2000**EN QUAD**\u2000, \u2000``EN QUAD``\u2000, \u2000`EN QUAD`\u2000,
+\u202f**NARROW NBSP**\u202f, \u202f``NARROW NBSP``\u202f, \u202f`NARROW NBSP`\u202f,
+""",                                      
+u"""\
+<document source="test data">
+    <paragraph>
+        inline markup separated by non-ASCII whitespace
+        \xa0
+        <strong>
+            NO-BREAK SPACE
+        \xa0, \xa0
+        <literal>
+            NO-BREAK SPACE
+        \xa0, \xa0
+        <title_reference>
+            NO-BREAK SPACE
+        \xa0,
+        \u2000
+        <strong>
+            EN QUAD
+        \u2000, \u2000
+        <literal>
+            EN QUAD
+        \u2000, \u2000
+        <title_reference>
+            EN QUAD
+        \u2000,
+        \u202f
+        <strong>
+            NARROW NBSP
+        \u202f, \u202f
+        <literal>
+            NARROW NBSP
+        \u202f, \u202f
+        <title_reference>
+            NARROW NBSP
+        \u202f,
+"""],
+[u"""\
+no inline markup due to whitespace inside and behind: *
+newline
+*
+* space * or one of
+*\xa0NO-BREAK SPACE\xa0*
+*\u1680OGHAM SPACE MARK\u1680*
+*\u2000EN QUAD\u2000*
+*\u2001EM QUAD\u2001*
+*\u2002EN SPACE\u2002*
+*\u2003EM SPACE\u2003*
+*\u2004THREE-PER-EM SPACE\u2004*
+*\u2005FOUR-PER-EM SPACE\u2005*
+*\u2006SIX-PER-EM SPACE\u2006*
+*\u2007FIGURE SPACE\u2007*
+*\u2008PUNCTUATION SPACE\u2008*
+*\u2009THIN SPACE\u2009*
+*\u200aHAIR SPACE\u200a*
+*\u202fNARROW NO-BREAK SPACE\u202f*
+*\u205fMEDIUM MATHEMATICAL SPACE\u205f*
+*\u3000IDEOGRAPHIC SPACE\u3000*
+*\u2028LINE SEPARATOR\u2028*
+""",
+u"""\
+<document source="test data">
+    <paragraph>
+        no inline markup due to whitespace inside and behind: *
+        newline
+        *
+        * space * or one of
+        *\xa0NO-BREAK SPACE\xa0*
+        *\u1680OGHAM SPACE MARK\u1680*
+        *\u2000EN QUAD\u2000*
+        *\u2001EM QUAD\u2001*
+        *\u2002EN SPACE\u2002*
+        *\u2003EM SPACE\u2003*
+        *\u2004THREE-PER-EM SPACE\u2004*
+        *\u2005FOUR-PER-EM SPACE\u2005*
+        *\u2006SIX-PER-EM SPACE\u2006*
+        *\u2007FIGURE SPACE\u2007*
+        *\u2008PUNCTUATION SPACE\u2008*
+        *\u2009THIN SPACE\u2009*
+        *\u200aHAIR SPACE\u200a*
+        *\u202fNARROW NO-BREAK SPACE\u202f*
+        *\u205fMEDIUM MATHEMATICAL SPACE\u205f*
+        *\u3000IDEOGRAPHIC SPACE\u3000*
+        *
+        LINE SEPARATOR
+        *"""],
+[u"""\
+no inline markup because of non-ASCII whitespace following /preceding the markup
+**\xa0NO-BREAK SPACE\xa0** ``\xa0NO-BREAK SPACE\xa0`` `\xa0NO-BREAK SPACE\xa0`
+**\u2000EN QUAD\u2000** ``\u2000EN QUAD\u2000`` `\u2000EN QUAD\u2000`
+**\u202fNARROW NBSP\u202f** ``\u202fNARROW NBSP\u202f`` `\u202fNARROW NBSP\u202f`
+""",
+u"""\
+<document source="test data">
+    <paragraph>
+        no inline markup because of non-ASCII whitespace following /preceding the markup
+        **\xa0NO-BREAK SPACE\xa0** ``\xa0NO-BREAK SPACE\xa0`` `\xa0NO-BREAK SPACE\xa0`
+        **\u2000EN QUAD\u2000** ``\u2000EN QUAD\u2000`` `\u2000EN QUAD\u2000`
+        **\u202fNARROW NBSP\u202f** ``\u202fNARROW NBSP\u202f`` `\u202fNARROW NBSP\u202f`\
+"""],
 # « * » ‹ * › « * » ‹ * › « * » ‹ * › French,
 [u"""\
 "Quoted" markup start-string (matched openers & closers) -> no markup:
