@@ -1,9 +1,7 @@
 #! /usr/bin/env python
 
-# Author: David Goodger
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 2975 $
-# Date: $Date: 2005-02-19 02:23:10 +0100 (Sat, 19 Feb 2005) $
+# $Id: test_option_lists.py 7128 2011-09-17 18:00:35Z grubert $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -683,6 +681,9 @@ Complex optargs:
 --source-url=<URL>      Use the supplied <URL> verbatim.
 --output-encoding=<name[:handler]>, -o<name[:handler]>
                         Specify the text encoding for output.
+--af=<filter1[=parameter1:parameter2:...],filter2,...>
+                        Setup a chain of audio filters.
+                        Option argument containing delimiter ``=``.
 -f <[path]filename>     Send output to file.
 -d <src dest>           Use diff from <src> to <dest>.
 --bogus=<x y z>         Bogus 3D coordinates.
@@ -717,6 +718,20 @@ Complex optargs:
             <description>
                 <paragraph>
                     Specify the text encoding for output.
+        <option_list_item>
+            <option_group>
+                <option>
+                    <option_string>
+                        --af
+                    <option_argument delimiter="=">
+                        <filter1[=parameter1:parameter2:...],filter2,...>
+            <description>
+                <paragraph>
+                    Setup a chain of audio filters.
+                    Option argument containing delimiter \n\
+                    <literal>
+                        =
+                    .
         <option_list_item>
             <option_group>
                 <option>
