@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_targets.py 4564 2006-05-21 20:44:42Z wiemann $
+# $Id: test_targets.py 7998 2016-12-16 03:45:07Z goodger $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -36,7 +36,7 @@ totest['targets'] = [
 <document source="test data">
     <target ids="optional-space-before-colon" names="optional\ space\ before\ colon">
 """],
-["""\
+[r"""
 External hyperlink targets:
 
 .. _one-liner: http://structuredtext.sourceforge.net
@@ -49,7 +49,10 @@ External hyperlink targets:
    http://structuredtext.
    sourceforge.net
 
-.. _not-indirect: uri\\_
+.. _escaped-whitespace: http://example.org/a\ path\ with\
+   spaces.html
+
+.. _not-indirect: uri\_
 """,
 """\
 <document source="test data">
@@ -58,6 +61,7 @@ External hyperlink targets:
     <target ids="one-liner" names="one-liner" refuri="http://structuredtext.sourceforge.net">
     <target ids="starts-on-this-line" names="starts-on-this-line" refuri="http://structuredtext.sourceforge.net">
     <target ids="entirely-below" names="entirely-below" refuri="http://structuredtext.sourceforge.net">
+    <target ids="escaped-whitespace" names="escaped-whitespace" refuri="http://example.org/a path with spaces.html">
     <target ids="not-indirect" names="not-indirect" refuri="uri_">
 """],
 ["""\
@@ -249,6 +253,30 @@ Paragraph.
             Paragraph.
 """],
 ["""\
+Duplicate implicit/directive targets.
+
+Title
+=====
+
+.. target-notes::
+   :name: title
+""",
+"""\
+<document source="test data">
+    <paragraph>
+        Duplicate implicit/directive targets.
+    <section dupnames="title" ids="title">
+        <title>
+            Title
+        <pending ids="id1" names="title">
+            <system_message backrefs="id1" level="1" line="4" source="test data" type="INFO">
+                <paragraph>
+                    Duplicate implicit target name: "title".
+            .. internal attributes:
+                 .transform: docutils.transforms.references.TargetNotes
+                 .details:
+"""],
+["""\
 Duplicate explicit targets.
 
 .. _title:
@@ -284,6 +312,30 @@ Third.
         Third.
 """],
 ["""\
+Duplicate explicit/directive targets.
+
+.. _title:
+
+First.
+
+.. rubric:: this is a title too
+   :name: title
+
+""",
+"""\
+<document source="test data">
+    <paragraph>
+        Duplicate explicit/directive targets.
+    <target dupnames="title" ids="title">
+    <paragraph>
+        First.
+    <rubric dupnames="title" ids="id1">
+        this is a title too
+        <system_message backrefs="id1" level="2" line="9" source="test data" type="WARNING">
+            <paragraph>
+                Duplicate explicit target name: "title".
+"""],
+["""\
 Duplicate targets:
 
 Target
@@ -291,7 +343,7 @@ Target
 
 Implicit section header target.
 
-.. [target] Citation target.
+.. [TARGET] Citation target.
 
 .. [#target] Autonumber-labeled footnote target.
 
@@ -300,6 +352,9 @@ Implicit section header target.
 Explicit internal target.
 
 .. _target: Explicit_external_target
+
+.. rubric:: directive with target
+   :name: Target
 """,
 """\
 <document source="test data">
@@ -312,7 +367,7 @@ Explicit internal target.
             Implicit section header target.
         <citation dupnames="target" ids="id1">
             <label>
-                target
+                TARGET
             <system_message backrefs="id1" level="1" line="8" source="test data" type="INFO">
                 <paragraph>
                     Duplicate implicit target name: "target".
@@ -334,6 +389,11 @@ Explicit internal target.
             <paragraph>
                 Duplicate explicit target name: "target".
         <target dupnames="target" ids="id4" refuri="Explicit_external_target">
+        <rubric dupnames="target" ids="id5">
+            directive with target
+            <system_message backrefs="id5" level="2" line="4" source="test data" type="WARNING">
+                <paragraph>
+                    Duplicate explicit target name: "target".
 """],
 ["""\
 .. _unescaped colon at end:: no good
