@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_substitutions.py 4667 2006-07-12 21:40:56Z wiemann $
+# $Id: test_substitutions.py 8067 2017-05-04 20:10:03Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -203,6 +203,7 @@ Use |sub| and |indirect1| and |sub| again (and |sub| one more time).
     <paragraph>
         Use \n\
         <problematic ids="id8" refid="id7">
+            |Sub|
          and \n\
         <problematic ids="id2" refid="id1">
             |indirect1|
@@ -222,7 +223,7 @@ Use |sub| and |indirect1| and |sub| again (and |sub| one more time).
     <system_message backrefs="id6" ids="id5" level="3" line="5" source="test data" type="ERROR">
         <paragraph>
             Circular substitution definition referenced: "sub".
-    <system_message backrefs="id8" ids="id7" level="3" source="test data" type="ERROR">
+    <system_message backrefs="id8" ids="id7" level="3" line="5" source="test data" type="ERROR">
         <paragraph>
             Circular substitution definition referenced: "Sub".
 """],
